@@ -526,7 +526,8 @@ static void dsp_memory_test(Hip *hip, unsigned short board)
 			fprintf(stderr, "1) The I/O base address is set incorrectly (ISA bus cards)\n");
 			fprintf(stderr, "2) The card is not installed\n");
 			fprintf(stderr, "3) Plug and Play BIOS error (see FAQ)\n");
-			exit(0);
+
+			throw VpbException("dsp_memory_test: failed");
 		}
 	}
 
