@@ -148,7 +148,6 @@ void OpenPri::HostDSPOpen()
 		/* setup chans structure */
 		chans[i].state = CH_IDLE;
 		chans[i].run = 0;
-		chans[i].layer1 = PRI_LAYER_1_ALAW;
 		chans[i].dtmf_dec = dtmf_init();
 		chans[i].chan_num = isdn_num;	// Channel number (not true ISDN as doesnt map above d-chan)
 		chans[i].cref = 0;
@@ -168,6 +167,7 @@ void OpenPri::HostDSPOpen()
 			chans[i].iface = &cardinfo->iface[iface_num];
 		}
 		chans[i].encoding = chans[i].iface->encoding;
+		chans[i].layer1 = (chans[i].iface->encoding == VPB_MULAW ? PRI_LAYER_1_ULAW : PRI_LAYER_1_ALAW);
 		chans[i].cause = 16;	// Set it as normal clear down
 		chans[i].cid = NULL;
 		chans[i].v = &m_reg;
@@ -770,7 +770,7 @@ bool OpenPri::ProcessCommands()
 
 	    case PC_SPI_SBRIDGE:
 		assert(mess[0] == PC_LSPI_SBRIDGE);
-		chans[idx].tx_fifo = m_reg.txdf[mess[3]];
+		chans[idx].tx_fifo = m_reg.txdf[mess[4]];
 		break;
 
 	    case PC_SPI_SBRIDGE_OFF:
