@@ -156,11 +156,26 @@ void iicout(int PCInn, int sig,int state);
 char iicin(int PCInn, int sig);
 
 #ifdef USE_UDEV
-#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,11)
-static struct class *vpb_class = NULL;
-#else
-static struct class_simple *vpb_class = NULL;
-#endif
+ #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13)
+  static struct class_simple *vpb_class;
+  #define class_create(x,y)              class_simple_create(x,y)
+  #define class_destroy(x)               class_simple_destroy(x)
+  #define device_create(c,p,n,d,u,...)   class_simple_device_add(c,n,NULL,u , ## __VA_ARGS__)
+  #define device_destroy(c,n)            class_simple_device_remove(n)
+
+ #elif LINUX_VERSION_CODE < KERNEL_VERSION(2,6,26)
+  static struct class *vpb_class;
+  #define device_create(c,p,n,d,u,...)   class_device_create(c,p,n,NULL,u , ## __VA_ARGS__)
+  #define device_destroy(c,n)            class_device_destroy(c,n)
+
+ #elif LINUX_VERSION_CODE < KERNEL_VERSION(2,6,27)
+  static struct class *vpb_class;
+  #define device_create(c,p,n,d,u,...)   device_create_drvdata(c,p,n,d,u , ## __VA_ARGS__)
+
+ #else
+  static struct class *vpb_class;
+
+ #endif
 #endif
 
 static struct file_operations vpb_fops={
@@ -212,13 +227,8 @@ int init_module(void)
 	char s[4];
 	struct pci_dev *dev = NULL;
 	unsigned short sn_low=0, sn_high=0;
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0)
-	u32 ret;
-#endif
+	int ret;
 	u32 reg28;
-	#ifdef USE_UDEV
-	char udev_name[50];
-	#endif
 
 	unsigned long tmp;
 
@@ -333,23 +343,25 @@ int init_module(void)
 
 	#ifdef USE_UDEV
 	printk(KERN_INFO NAME": Setting up udev...\n");
-	sprintf(udev_name, NAME"%d", 0);
-	#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,14)
+
 	vpb_class = class_create(THIS_MODULE, NAME);
-	class_device_create(vpb_class, NULL, MKDEV(major, 0), NULL, udev_name);
-	#else
-	#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,11)
-	vpb_class = class_create(THIS_MODULE, NAME);
-	class_device_create(vpb_class, MKDEV(major, 0), NULL, udev_name);
-	#else
-	vpb_class = class_simple_create(THIS_MODULE, NAME);
-	class_simple_device_add(vpb_class, MKDEV(major, 0), NULL, udev_name);
-	#endif
-	#endif
+
+	{
+	    struct device *d = device_create(vpb_class, NULL, MKDEV(major, 0), NULL, "vpb0");
+	    if( IS_ERR(d) ) {
+		    ret = PTR_ERR(d);
+		    goto hell;
+	    }
+	}
 	#endif
 	printk(KERN_INFO NAME ":%d V4PCI's detected on PCI bus\n",numPCI);
 
 	return 0;
+
+    hell:
+
+	cleanup_module();
+	return ret;
 }
 
 /*--------------------------------------------------------------------------*\
@@ -381,13 +393,8 @@ void cleanup_module(void)
 	}
 
 	#ifdef USE_UDEV
-	#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,11)
-	class_device_destroy(vpb_class,MKDEV(major, 0));
+	device_destroy(vpb_class,MKDEV(major, 0));
 	class_destroy(vpb_class);
-	#else
-	class_simple_device_remove(MKDEV(major, 0));
-	class_simple_destroy(vpb_class);
-	#endif
 	#endif
 
 	unregister_chrdev(major, NAME);
