@@ -61,7 +61,7 @@
 #define LINEAR2FOOLAW_LUT_SIZE  0x10000
 #define LINEAR2FOOLAW_LUT_PAGES get_order(LINEAR2FOOLAW_LUT_SIZE)
 
-static struct vt_class_device {
+static struct vtcore_device {
 	short                   alaw2linear_lut[0x100];
 	short                   mulaw2linear_lut[0x100];
 	unsigned char          *linear2alaw_lut;     //[0x10000]
@@ -74,7 +74,7 @@ static struct vt_class_device {
 	atomic_t                inuse;
 } *vtcore;
 
-// You must hold this lock anytime you access or modify the vt_class_device struct.
+// You must hold this lock anytime you access or modify the vtcore_device struct.
 DEFINE_MUTEX(vtcore_mutex);
 
 
@@ -106,12 +106,25 @@ MODULE_PARM_DESC(debug, "Set the logging verbosity");
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13)
  static struct class_simple *vt_class;
+ #define device                         class_device
  #define class_create(x,y)              class_simple_create(x,y)
  #define class_destroy(x)               class_simple_destroy(x)
- #define class_device_create(c,p,n,d,u) class_simple_device_add(c,n,d,u)
- #define class_device_destroy(c,n)      class_simple_device_remove(n)
+ #define device_create(c,p,n,d,u,...)   class_simple_device_add(c,n,NULL,u , ## __VA_ARGS__)
+ #define device_destroy(c,n)            class_simple_device_remove(n)
+
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(2,6,26)
+ static struct class *vt_class;
+ #define device                         class_device
+ #define device_create(c,p,n,d,u,...)   class_device_create(c,p,n,NULL,u , ## __VA_ARGS__)
+ #define device_destroy(c,n)            class_device_destroy(c,n)
+
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(2,6,27)
+ static struct class *vt_class;
+ #define device_create(c,p,n,d,u,...)   device_create_drvdata(c,p,n,d,u , ## __VA_ARGS__)
+
 #else
  static struct class *vt_class;
+
 #endif
 
 
@@ -222,22 +235,22 @@ int __init vtcore_init(void)
 	int y,ret;
 	short *alaw2lin, *mulaw2lin;
 	unsigned char *lin2alaw, *lin2mulaw;
-	struct class_device *class_dev;
+	struct device *d;
 
 	info(DRIVER_DESCRIPTION " " VT_VERSION " for linux " UTS_RELEASE);
 
 	if( mutex_lock_interruptible(&vtcore_mutex) ) return -ERESTARTSYS;
 	if( vtcore ) goto exit;
 
-	vtcore = kzalloc(sizeof(struct vt_class_device), GFP_KERNEL);
+	vtcore = kzalloc(sizeof(struct vtcore_device), GFP_KERNEL);
 	if( !vtcore ) {
 		crit("Failed to allocate vtcore structure of size %d",
-		     (int)sizeof(struct vt_class_device));
+		     (int)sizeof(struct vtcore_device));
 		ret = -ENOMEM;
 		goto hell;
 	}
 	atomic_set( &vtcore->inuse, 0 );
-	//info("sizeof vt_class_device = %d",sizeof(struct vt_class_device));
+	//info("sizeof vtcore_device = %d",sizeof(struct vtcore_device));
 
 	ret = alloc_chrdev_region(&vtcore->dev, 0, 1, NAME);
 	if( ret < 0 ) {
@@ -285,9 +298,9 @@ int __init vtcore_init(void)
 		ret = PTR_ERR(vt_class);
 		goto hell_5;
 	}
-	class_dev = class_device_create(vt_class, NULL, vtcore->dev, NULL, "vt0");
-	if( IS_ERR(class_dev) ) {
-		ret = PTR_ERR(class_dev);
+	d = device_create(vt_class, NULL, vtcore->dev, NULL, "vt0");
+	if( IS_ERR(d) ) {
+		ret = PTR_ERR(d);
 		goto hell_6;
 	}
 
@@ -316,7 +329,7 @@ int __init vtcore_init(void)
 	return 0;
 
     hell_7:
-	class_device_destroy(vt_class, vtcore->dev);
+	device_destroy(vt_class, vtcore->dev);
     hell_6:
 	class_destroy(vt_class);
 	vt_class = NULL;
@@ -345,7 +358,7 @@ void __exit vtcore_exit(void)
 	}
 
 	cdev_del(&vtcore->cdev);
-	class_device_destroy(vt_class, vtcore->dev);
+	device_destroy(vt_class, vtcore->dev);
 	class_destroy(vt_class);
 	vt_class = NULL;
 	free_pages((unsigned long)vtcore->linear2mulaw_lut, LINEAR2FOOLAW_LUT_PAGES);
@@ -1334,9 +1347,8 @@ int vt_board_register(struct vtboard *board)
 
 	for(i=0; i < board->maxports; ++i)
 	{
-		struct channel      *chan         = &board->chans[i];
-		char                 cdevname[32] = { 0 };
-		struct class_device *cd;
+		struct channel *chan = &board->chans[i];
+		struct device  *d;
 
 		chan->state   = CH_IDLE;
 		chan->echocan = NULL;
@@ -1378,15 +1390,14 @@ int vt_board_register(struct vtboard *board)
 
 
 	#define CREATE_PORT_DEVICE(name,i)					    \
-		snprintf( cdevname, sizeof(cdevname)-1,				    \
-			  "vtboard%d" #name "%d", board->boardnum, i );		    \
-		cd = class_device_create( vt_class, NULL,			    \
-					  MKDEV( MAJOR(board->name##_dev),	    \
-						 MINOR(board->name##_dev) + i ),    \
-					  NULL, cdevname );			    \
-		if( IS_ERR(cd) ) {						    \
+		d = device_create( vt_class, NULL,				    \
+				   MKDEV( MAJOR(board->name##_dev),		    \
+					  MINOR(board->name##_dev) + i ),	    \
+				   NULL,					    \
+				   "vtboard%d" #name "%d", board->boardnum, i );    \
+		if( IS_ERR(d) ) {						    \
 			portcrit(board,i,"FAILED to register " #name " device (%ld)", \
-				 PTR_ERR(cd));					    \
+				 PTR_ERR(d));					    \
 		}
 
 		CREATE_PORT_DEVICE(tap, i);
@@ -1516,8 +1527,8 @@ void vt_board_unregister(struct vtboard *board)
 			continue;
 		}
 
-		class_device_destroy( vt_class, MKDEV( MAJOR(board->tap_dev),
-						       MINOR(board->tap_dev) + i ) );
+		device_destroy( vt_class, MKDEV( MAJOR(board->tap_dev),
+						 MINOR(board->tap_dev) + i ) );
 
 		if( chan->procfs_root ) {
 			char  dirname[8] = { [0 ... 7] = 0 };
