@@ -765,7 +765,7 @@ static int set_play_gain(struct openpci *card, int port, int gain)
 
 	    case VT_PORT_PROSLIC:
 		// Set just the digital gain, but there is an analogue
-		// gain stage that we can manilpulate too if required.
+		// gain stage that we can manipulate too if required.
 		// For SLIC, tx and rx are relative to the handset.
 		if( ! write_indreg_fxs(card, port, PSI_RX_DIG_GAIN, proslic_gain(gain)) )
 			return -EIO;
@@ -1269,7 +1269,7 @@ static int vtopenpci_ioctl(struct vtboard *board, int port, unsigned int cmd, vo
 		outb(port,PIB(1));  ++card->armbout; HTXF_WAIT_LOCKED_RET(-EIO);
 		outb((length & 0xffff) / 10, PIB(1));
 				    ++card->armbout; HTXF_WAIT_LOCKED_RET(-EIO);
-		outb((length >> 16) / 10, PIB(1));
+		outb((length >> 16) / (card->firmware < 15 ? 10 : 100), PIB(1));
 				    ++card->armbout; HTXF_WAIT_LOCKED_RET(-EIO);
 		spin_unlock_irqrestore(&card->lock, flags);
 		break;
