@@ -65,7 +65,6 @@
 
 void *call_gen_thread(void *pv);
 void *call_rec_thread(void *pv);
-int arg_exists(int argc, char *argv[], char *arg);
 
 int             threads_active; // the number of active threads.
 pthread_mutex_t mutex;          // mutex to protect shared data
@@ -83,11 +82,12 @@ typedef struct {
 	int	run;
 } CHAN_INFO;
 
-void myprintf(char *fmt, ...);
+void myprintf(const char *fmt, ...);
 
 void call_failed(int handle,int progress);
 void call_passed(int handle);
 
+
 int main(int argc, char * argv[])
 {
 
@@ -551,7 +551,7 @@ void *call_rec_thread(void *pv) {
 	return NULL;
 }
 
-void myprintf(char *fmt, ...)
+void myprintf(const char *fmt, ...)
 {
 	va_list argptr;
 	time_t  curtime;
